@@ -6,6 +6,7 @@ import six
 import math
 import os
 import sys
+import errno
 import re
 import shutil
 import tempfile
@@ -14,6 +15,8 @@ import atexit
 import weakref
 import warnings
 
+import numpy as np
+
 import matplotlib as mpl
 from matplotlib.backend_bases import RendererBase, GraphicsContextBase,\
     FigureManagerBase, FigureCanvasBase
@@ -33,17 +36,16 @@ from matplotlib.compat.subprocess import check_output
 system_fonts = []
 if sys.platform.startswith('win'):
     from matplotlib import font_manager
-    from matplotlib.ft2font import FT2Font
     for f in font_manager.win32InstalledFonts():
         try:
-            system_fonts.append(FT2Font(str(f)).family_name)
+            system_fonts.append(font_manager.get_font(str(f)).family_name)
         except:
             pass # unknown error, skip this font
 else:
     # assuming fontconfig is installed and the command 'fc-list' exists
     try:
         # list scalable (non-bitmap) fonts
-        fc_list = check_output(['fc-list', ':outline,scalable', 'family'])
+        fc_list = check_output([str('fc-list'), ':outline,scalable', 'family'])
         fc_list = fc_list.decode('utf8')
         system_fonts = [f.split(',')[0] for f in fc_list.splitlines()]
         system_fonts = list(set(system_fonts))
@@ -177,7 +179,7 @@ def make_pdf_to_png_converter():
     tools_available = []
     # check for pdftocairo
     try:
-        check_output(["pdftocairo", "-v"], stderr=subprocess.STDOUT)
+        check_output([str("pdftocairo"), "-v"], stderr=subprocess.STDOUT)
         tools_available.append("pdftocairo")
     except:
         pass
@@ -189,14 +191,13 @@ def make_pdf_to_png_converter():
     # pick converter
     if "pdftocairo" in tools_available:
         def cairo_convert(pdffile, pngfile, dpi):
-            cmd = ["pdftocairo", "-singlefile", "-png",
-                   "-r %d" % dpi, pdffile, os.path.splitext(pngfile)[0]]
-            # for some reason this doesn't work without shell
-            check_output(" ".join(cmd), shell=True, stderr=subprocess.STDOUT)
+            cmd = [str("pdftocairo"), "-singlefile", "-png", "-r", "%d" % dpi,
+                   pdffile, os.path.splitext(pngfile)[0]]
+            check_output(cmd, stderr=subprocess.STDOUT)
         return cairo_convert
     elif "gs" in tools_available:
         def gs_convert(pdffile, pngfile, dpi):
-            cmd = [gs, '-dQUIET', '-dSAFER', '-dBATCH', '-dNOPAUSE', '-dNOPROMPT',
+            cmd = [str(gs), '-dQUIET', '-dSAFER', '-dBATCH', '-dNOPAUSE', '-dNOPROMPT',
                    '-sDEVICE=png16m', '-dUseCIEColor', '-dTextAlphaBits=4',
                    '-dGraphicsAlphaBits=4', '-dDOINTERPOLATE', '-sOutputFile=%s' % pngfile,
                    '-r%d' % dpi, pdffile]
@@ -212,7 +213,7 @@ class LatexError(Exception):
         self.latex_output = latex_output
 
 
-class LatexManagerFactory:
+class LatexManagerFactory(object):
     previous_instance = None
 
     @staticmethod
@@ -233,31 +234,14 @@ class LatexManagerFactory:
             LatexManagerFactory.previous_instance = new_inst
             return new_inst
 
-class WeakSet:
-    # TODO: Poor man's weakref.WeakSet.
-    #       Remove this once python 2.6 support is dropped from matplotlib.
 
-    def __init__(self):
-        self.weak_key_dict = weakref.WeakKeyDictionary()
-
-    def add(self, item):
-        self.weak_key_dict[item] = None
-
-    def discard(self, item):
-        if item in self.weak_key_dict:
-            del self.weak_key_dict[item]
-
-    def __iter__(self):
-        return six.iterkeys(self.weak_key_dict)
-
-
-class LatexManager:
+class LatexManager(object):
     """
     The LatexManager opens an instance of the LaTeX application for
     determining the metrics of text elements. The LaTeX environment can be
     modified by setting fonts and/or a custem preamble in the rc parameters.
     """
-    _unclean_instances = WeakSet()
+    _unclean_instances = weakref.WeakSet()
 
     @staticmethod
     def _build_latex_header():
@@ -301,6 +285,11 @@ class LatexManager:
         return self._expect("\n*")
 
     def __init__(self):
+        # store references for __del__
+        self._os_path = os.path
+        self._shutil = shutil
+        self._debug = rcParams.get("pgf.debug", False)
+
         # create a tmp directory for running latex, remember to cleanup
         self.tmpdir = tempfile.mkdtemp(prefix="mpl_pgf_lm_")
         LatexManager._unclean_instances.add(self)
@@ -310,19 +299,25 @@ class LatexManager:
         self.latex_header = LatexManager._build_latex_header()
         latex_end = "\n\\makeatletter\n\\@@end\n"
         try:
-            latex = subprocess.Popen([self.texcommand, "-halt-on-error"],
+            latex = subprocess.Popen([str(self.texcommand), "-halt-on-error"],
                                      stdin=subprocess.PIPE,
                                      stdout=subprocess.PIPE,
                                      cwd=self.tmpdir)
-        except OSError:
-            raise RuntimeError("Error starting process '%s'" % self.texcommand)
+        except OSError as e:
+            if e.errno == errno.ENOENT:
+                raise RuntimeError("Latex command not found. "
+                    "Install '%s' or change pgf.texsystem to the desired command."
+                    % self.texcommand
+                )
+            else:
+                raise RuntimeError("Error starting process '%s'" % self.texcommand)
         test_input = self.latex_header + latex_end
         stdout, stderr = latex.communicate(test_input.encode("utf-8"))
         if latex.returncode != 0:
             raise LatexError("LaTeX returned an error, probably missing font or error in preamble:\n%s" % stdout)
 
         # open LaTeX process for real work
-        latex = subprocess.Popen([self.texcommand, "-halt-on-error"],
+        latex = subprocess.Popen([str(self.texcommand), "-halt-on-error"],
                                  stdin=subprocess.PIPE, stdout=subprocess.PIPE,
                                  cwd=self.tmpdir)
         self.latex = latex
@@ -337,22 +332,22 @@ class LatexManager:
         self.str_cache = {}
 
     def _cleanup(self):
-        if not os.path.isdir(self.tmpdir):
+        if not self._os_path.isdir(self.tmpdir):
             return
         try:
-            self.latex_stdin_utf8.close()
             self.latex.communicate()
-            self.latex.wait()
+            self.latex_stdin_utf8.close()
+            self.latex.stdout.close()
         except:
             pass
         try:
-            shutil.rmtree(self.tmpdir)
+            self._shutil.rmtree(self.tmpdir)
             LatexManager._unclean_instances.discard(self)
         except:
             sys.stderr.write("error deleting tmp directory %s\n" % self.tmpdir)
 
     def __del__(self):
-        if rcParams.get("pgf.debug", False):
+        if self._debug:
             print("deleting LatexManager")
         self._cleanup()
 
@@ -429,7 +424,10 @@ class RendererPgf(RendererBase):
                     self.__dict__[m] = nop
         else:
             # if fh does not belong to a filename, deactivate draw_image
-            if not os.path.exists(fh.name):
+            if not hasattr(fh, 'name') or not os.path.exists(fh.name):
+                warnings.warn("streamed pgf-code does not support raster "
+                              "graphics, consider using the pgf-to-pdf option",
+                              UserWarning)
                 self.__dict__["draw_image"] = lambda *args, **kwargs: None
 
     def draw_markers(self, gc, marker_path, marker_trans, path, trans, rgbFace=None):
@@ -466,7 +464,7 @@ class RendererPgf(RendererBase):
         # draw the path
         self._print_pgf_clip(gc)
         self._print_pgf_path_styles(gc, rgbFace)
-        self._print_pgf_path(gc, path, transform)
+        self._print_pgf_path(gc, path, transform, rgbFace)
         self._pgf_path_draw(stroke=gc.get_linewidth() != 0.0,
                             fill=rgbFace is not None)
         writeln(self.fh, r"\end{pgfscope}")
@@ -478,7 +476,7 @@ class RendererPgf(RendererBase):
 
             # combine clip and path for clipping
             self._print_pgf_clip(gc)
-            self._print_pgf_path(gc, path, transform)
+            self._print_pgf_path(gc, path, transform, rgbFace)
             writeln(self.fh, r"\pgfusepath{clip}")
 
             # build pattern definition
@@ -572,11 +570,11 @@ class RendererPgf(RendererBase):
             dash_str += r"}{%fpt}" % dash_offset
             writeln(self.fh, dash_str)
 
-    def _print_pgf_path(self, gc, path, transform):
+    def _print_pgf_path(self, gc, path, transform, rgbFace=None):
         f = 1. / self.dpi
-        # check for clip box
+        # check for clip box / ignore clip for filled paths
         bbox = gc.get_clip_rectangle() if gc else None
-        if bbox:
+        if bbox and (rgbFace is None):
             p1, p2 = bbox.get_points()
             clip = (p1[0], p1[1], p2[0], p2[1])
         else:
@@ -610,25 +608,51 @@ class RendererPgf(RendererBase):
             actions.append("fill")
         writeln(self.fh, r"\pgfusepath{%s}" % ",".join(actions))
 
-    def draw_image(self, gc, x, y, im):
-        # TODO: Almost no documentation for the behavior of this function.
-        #       Something missing?
+    def option_scale_image(self):
+        """
+        pgf backend supports affine transform of image.
+        """
+        return True
+
+    def option_image_nocomposite(self):
+        """
+        return whether to generate a composite image from multiple images on
+        a set of axes
+        """
+        return not rcParams['image.composite_image']
+
+    def draw_image(self, gc, x, y, im, transform=None):
+        h, w = im.shape[:2]
+        if w == 0 or h == 0:
+            return
 
         # save the images to png files
         path = os.path.dirname(self.fh.name)
         fname = os.path.splitext(os.path.basename(self.fh.name))[0]
         fname_img = "%s-img%d.png" % (fname, self.image_counter)
         self.image_counter += 1
-        im.flipud_out()
-        rows, cols, buf = im.as_rgba_str()
-        _png.write_png(buf, cols, rows, os.path.join(path, fname_img))
+        _png.write_png(im[::-1], os.path.join(path, fname_img))
 
         # reference the image in the pgf picture
         writeln(self.fh, r"\begin{pgfscope}")
         self._print_pgf_clip(gc)
-        h, w = im.get_size_out()
         f = 1. / self.dpi  # from display coords to inch
-        writeln(self.fh, r"\pgftext[at=\pgfqpoint{%fin}{%fin},left,bottom]{\pgfimage[interpolate=true,width=%fin,height=%fin]{%s}}" % (x * f, y * f, w * f, h * f, fname_img))
+        if transform is None:
+            writeln(self.fh,
+                    r"\pgfsys@transformshift{%fin}{%fin}" % (x * f, y * f))
+            w, h = w * f, h * f
+        else:
+            tr1, tr2, tr3, tr4, tr5, tr6 = transform.frozen().to_values()
+            writeln(self.fh,
+                    r"\pgfsys@transformcm{%f}{%f}{%f}{%f}{%fin}{%fin}" %
+                    (tr1 * f, tr2 * f, tr3 * f, tr4 * f,
+                     (tr5 + x) * f, (tr6 + y) * f))
+            w = h = 1  # scale is already included in the transform
+        interp = str(transform is None).lower()  # interpolation in PDF reader
+        writeln(self.fh,
+                r"\pgftext[left,bottom]"
+                r"{\pgfimage[interpolate=%s,width=%fin,height=%fin]{%s}}" %
+                (interp, w, h, fname_img))
         writeln(self.fh, r"\end{pgfscope}")
 
     def draw_tex(self, gc, x, y, s, prop, angle, ismath="TeX!", mtext=None):
@@ -638,7 +662,7 @@ class RendererPgf(RendererBase):
         # prepare string for tex
         s = common_texification(s)
         prop_cmds = _font_properties_str(prop)
-        s = r"{%s %s}" % (prop_cmds, s)
+        s = r"%s %s" % (prop_cmds, s)
 
 
         writeln(self.fh, r"\begin{pgfscope}")
@@ -652,10 +676,14 @@ class RendererPgf(RendererBase):
             writeln(self.fh, r"\definecolor{textcolor}{rgb}{%f,%f,%f}" % rgb)
             writeln(self.fh, r"\pgfsetstrokecolor{textcolor}")
             writeln(self.fh, r"\pgfsetfillcolor{textcolor}")
+            s = r"\color{textcolor}" + s
 
         f = 1.0 / self.figure.dpi
         text_args = []
-        if mtext and (angle == 0 or mtext.get_rotation_mode() == "anchor"):
+        if mtext and (
+                (angle == 0 or
+                 mtext.get_rotation_mode() == "anchor") and
+                mtext.get_va() != "center_baseline"):
             # if text anchoring can be supported, get the original coordinates
             # and add alignment information
             x, y = mtext.get_transform().transform_point(mtext.get_position())
@@ -737,7 +765,7 @@ def new_figure_manager_given_figure(num, figure):
     return manager
 
 
-class TmpDirCleaner:
+class TmpDirCleaner(object):
     remaining_tmpdirs = set()
 
     @staticmethod
@@ -758,9 +786,6 @@ class FigureCanvasPgf(FigureCanvasBase):
                  "pdf": "LaTeX compiled PGF picture",
                  "png": "Portable Network Graphics", }
 
-    def __init__(self, *args):
-        FigureCanvasBase.__init__(self, *args)
-
     def get_default_filetype(self):
         return 'pdf'
 
@@ -834,11 +859,8 @@ class FigureCanvasPgf(FigureCanvasBase):
             with codecs.open(fname_or_fh, "w", encoding="utf-8") as fh:
                 self._print_pgf_to_fh(fh, *args, **kwargs)
         elif is_writable_file_like(fname_or_fh):
-            if not os.path.exists(fname_or_fh.name):
-                warnings.warn("streamed pgf-code does not support raster "
-                              "graphics, consider using the pgf-to-pdf option",
-                              UserWarning)
-            self._print_pgf_to_fh(fname_or_fh, *args, **kwargs)
+            fh = codecs.getwriter("utf-8")(fname_or_fh)
+            self._print_pgf_to_fh(fh, *args, **kwargs)
         else:
             raise ValueError("filename must be a path")
 
@@ -872,7 +894,7 @@ class FigureCanvasPgf(FigureCanvasBase):
                 fh_tex.write(latexcode)
 
             texcommand = get_texcommand()
-            cmdargs = [texcommand, "-interaction=nonstopmode",
+            cmdargs = [str(texcommand), "-interaction=nonstopmode",
                        "-halt-on-error", "figure.tex"]
             try:
                 check_output(cmdargs, stderr=subprocess.STDOUT, cwd=tmpdir)
