@@ -148,11 +148,6 @@ class Dvi(object):
         while True:
             byte = ord(self.file.read(1)[0])
             self._dispatch(byte)
-#             if self.state == _dvistate.inpage:
-#                 matplotlib.verbose.report(
-#                     'Dvi._read: after %d at %f,%f' %
-#                     (byte, self.h, self.v),
-#                     'debug-annoying')
             if byte == 140: # end of page
                 return True
             if self.state == _dvistate.post_post: # end of file
@@ -282,9 +277,6 @@ class Dvi(object):
         if font._vf is None:
             self.text.append((self.h, self.v, font, char,
                               font._width_of(char)))
-#             matplotlib.verbose.report(
-#                 'Dvi._put_char: %d,%d %d' %(self.h, self.v, char),
-#                 'debug-annoying')
         else:
             scale = font._scale
             for x, y, f, g, w in font._vf[char].text:
@@ -303,9 +295,6 @@ class Dvi(object):
             raise ValueError("misplaced put_rule in dvi file")
         if a > 0 and b > 0:
             self.boxes.append((self.h, self.v, a, b))
-#             matplotlib.verbose.report(
-#                 'Dvi._put_rule: %d,%d %d,%d' % (self.h, self.v, a, b),
-#                 'debug-annoying')
 
     def _nop(self):
         pass
@@ -395,15 +384,18 @@ class Dvi(object):
                 'debug')
 
     def _fnt_def(self, k, c, s, d, a, l, n):
-        tfm = _tfmfile(n[-l:].decode('ascii'))
+        fontname = n[-l:].decode('ascii')
+        tfm = _tfmfile(fontname)
+        if tfm is None:
+            if six.PY2:
+                error_class = OSError
+            else:
+                error_class = FileNotFoundError
+            raise error_class("missing font metrics file: %s" % fontname)
         if c != 0 and tfm.checksum != 0 and c != tfm.checksum:
             raise ValueError('tfm checksum mismatch: %s'%n)
-        # It seems that the assumption behind the following check is incorrect:
-        #if d != tfm.design_size:
-        #    raise ValueError, 'tfm design size mismatch: %d in dvi, %d in %s'%\
-        #        (d, tfm.design_size, n)
 
-        vf = _vffile(n[-l:].decode('ascii'))
+        vf = _vffile(fontname)
 
         self.fonts[k] = DviFont(scale=s, tfm=tfm, texname=n, vf=vf)
 
@@ -849,7 +841,7 @@ def find_tex_file(filename, format=None):
     """
     Call :program:`kpsewhich` to find a file in the texmf tree. If
     *format* is not None, it is used as the value for the
-    :option:`--format` option.
+    `--format` option.
 
     Apparently most existing TeX distributions on Unix-like systems
     use kpathsea. I hear MikTeX (a popular distribution on Windows)
@@ -861,7 +853,7 @@ def find_tex_file(filename, format=None):
         The library that :program:`kpsewhich` is part of.
     """
 
-    cmd = ['kpsewhich']
+    cmd = [str('kpsewhich')]
     if format is not None:
         cmd += ['--format=' + format]
     cmd += [filename]
