@@ -24,6 +24,7 @@ import warnings
 import matplotlib.transforms as mtransforms
 import matplotlib.artist as martist
 import matplotlib.text as mtext
+import matplotlib.path as mpath
 import numpy as np
 from matplotlib.transforms import Bbox, BboxBase, TransformedBbox
 
@@ -174,6 +175,7 @@ class OffsetBox(martist.Artist):
         from .cbook import _InstanceMethodPickler
         if isinstance(self._offset, _InstanceMethodPickler):
             self._offset = self._offset.get_instancemethod()
+        self.stale = True
 
     def set_figure(self, fig):
         """
@@ -185,6 +187,14 @@ class OffsetBox(martist.Artist):
         for c in self.get_children():
             c.set_figure(fig)
 
+    @martist.Artist.axes.setter
+    def axes(self, ax):
+        # TODO deal with this better
+        martist.Artist.axes.fset(self, ax)
+        for c in self.get_children():
+            if c is not None:
+                c.axes = ax
+
     def contains(self, mouseevent):
         for c in self.get_children():
             a, b = c.contains(mouseevent)
@@ -199,6 +209,7 @@ class OffsetBox(martist.Artist):
         accepts x, y, tuple, or a callable object.
         """
         self._offset = xy
+        self.stale = True
 
     def get_offset(self, width, height, xdescent, ydescent, renderer):
         """
@@ -218,6 +229,7 @@ class OffsetBox(martist.Artist):
         accepts float
         """
         self.width = width
+        self.stale = True
 
     def set_height(self, height):
         """
@@ -226,6 +238,7 @@ class OffsetBox(martist.Artist):
         accepts float
         """
         self.height = height
+        self.stale = True
 
     def get_visible_children(self):
         """
@@ -273,6 +286,7 @@ class OffsetBox(martist.Artist):
             c.draw(renderer)
 
         bbox_artist(self, renderer, fill=False, props=dict(pad=0.))
+        self.stale = False
 
 
 class PackerBase(OffsetBox):
@@ -541,6 +555,7 @@ class PaddedBox(OffsetBox):
             c.draw(renderer)
 
         #bbox_artist(self, renderer, fill=False, props=dict(pad=0.))
+        self.stale = False
 
     def update_frame(self, bbox, fontsize=None):
         self.patch.set_bounds(bbox.x0, bbox.y0,
@@ -548,6 +563,7 @@ class PaddedBox(OffsetBox):
 
         if fontsize:
             self.patch.set_mutation_scale(fontsize)
+        self.stale = True
 
     def draw_frame(self, renderer):
         # update the location and size of the legend
@@ -562,14 +578,16 @@ class DrawingArea(OffsetBox):
     """
     The DrawingArea can contain any Artist as a child. The DrawingArea
     has a fixed width and height. The position of children relative to
-    the parent is fixed.
+    the parent is fixed. The children can be clipped at the
+    boundaries of the parent.
     """
 
     def __init__(self, width, height, xdescent=0.,
-                 ydescent=0., clip=True):
+                 ydescent=0., clip=False):
         """
         *width*, *height* : width and height of the container box.
         *xdescent*, *ydescent* : descent of the box in x- and y-direction.
+        *clip* : Whether to clip the children
         """
 
         super(DrawingArea, self).__init__()
@@ -578,6 +596,7 @@ class DrawingArea(OffsetBox):
         self.height = height
         self.xdescent = xdescent
         self.ydescent = ydescent
+        self._clip_children = clip
 
         self.offset_transform = mtransforms.Affine2D()
         self.offset_transform.clear()
@@ -585,6 +604,19 @@ class DrawingArea(OffsetBox):
 
         self.dpi_transform = mtransforms.Affine2D()
 
+    @property
+    def clip_children(self):
+        """
+        If the children of this DrawingArea should be clipped
+        by DrawingArea bounding box.
+        """
+        return self._clip_children
+
+    @clip_children.setter
+    def clip_children(self, val):
+        self._clip_children = bool(val)
+        self.stale = True
+
     def get_transform(self):
         """
         Return the :class:`~matplotlib.transforms.Transform` applied
@@ -608,6 +640,7 @@ class DrawingArea(OffsetBox):
 
         self.offset_transform.clear()
         self.offset_transform.translate(xy[0], xy[1])
+        self.stale = True
 
     def get_offset(self):
         """
@@ -638,6 +671,11 @@ class DrawingArea(OffsetBox):
         self._children.append(a)
         if not a.is_transform_set():
             a.set_transform(self.get_transform())
+        if self.axes is not None:
+            a.axes = self.axes
+        fig = self.figure
+        if fig is not None:
+            a.set_figure(fig)
 
     def draw(self, renderer):
         """
@@ -648,10 +686,21 @@ class DrawingArea(OffsetBox):
         self.dpi_transform.clear()
         self.dpi_transform.scale(dpi_cor, dpi_cor)
 
+        # At this point the DrawingArea has a transform
+        # to the display space so the path created is
+        # good for clipping children
+        tpath = mtransforms.TransformedPath(
+            mpath.Path([[0, 0], [0, self.height],
+                        [self.width, self.height],
+                        [self.width, 0]]),
+            self.get_transform())
         for c in self._children:
+            if self._clip_children and not (c.clipbox or c._clippath):
+                c.set_clip_path(tpath)
             c.draw(renderer)
 
         bbox_artist(self, renderer, fill=False, props=dict(pad=0.))
+        self.stale = False
 
 
 class TextArea(OffsetBox):
@@ -705,11 +754,12 @@ class TextArea(OffsetBox):
         self._minimumdescent = minimumdescent
 
     def set_text(self, s):
-        "set text"
+        "Set the text of this area as a string."
         self._text.set_text(s)
+        self.stale = True
 
     def get_text(self):
-        "get text"
+        "Returns the string representation of this area's text"
         return self._text.get_text()
 
     def set_multilinebaseline(self, t):
@@ -721,6 +771,7 @@ class TextArea(OffsetBox):
         singleline text.
         """
         self._multilinebaseline = t
+        self.stale = True
 
     def get_multilinebaseline(self):
         """
@@ -736,6 +787,7 @@ class TextArea(OffsetBox):
         it has minimum descent of "p"
         """
         self._minimumdescent = t
+        self.stale = True
 
     def get_minimumdescent(self):
         """
@@ -759,6 +811,7 @@ class TextArea(OffsetBox):
 
         self.offset_transform.clear()
         self.offset_transform.translate(xy[0], xy[1])
+        self.stale = True
 
     def get_offset(self):
         """
@@ -814,6 +867,7 @@ class TextArea(OffsetBox):
         self._text.draw(renderer)
 
         bbox_artist(self, renderer, fill=False, props=dict(pad=0.))
+        self.stale = False
 
 
 class AuxTransformBox(OffsetBox):
@@ -848,6 +902,7 @@ class AuxTransformBox(OffsetBox):
         'Add any :class:`~matplotlib.artist.Artist` to the container box'
         self._children.append(a)
         a.set_transform(self.get_transform())
+        self.stale = True
 
     def get_transform(self):
         """
@@ -874,6 +929,7 @@ class AuxTransformBox(OffsetBox):
 
         self.offset_transform.clear()
         self.offset_transform.translate(xy[0], xy[1])
+        self.stale = True
 
     def get_offset(self):
         """
@@ -918,6 +974,7 @@ class AuxTransformBox(OffsetBox):
             c.draw(renderer)
 
         bbox_artist(self, renderer, fill=False, props=dict(pad=0.))
+        self.stale = False
 
 
 class AnchoredOffsetbox(OffsetBox):
@@ -997,6 +1054,9 @@ class AnchoredOffsetbox(OffsetBox):
     def set_child(self, child):
         "set the child to be anchored"
         self._child = child
+        if child is not None:
+            child.axes = self.axes
+        self.stale = True
 
     def get_child(self):
         "return the child"
@@ -1054,6 +1114,7 @@ class AnchoredOffsetbox(OffsetBox):
             self._bbox_to_anchor = Bbox.from_bounds(*bbox)
 
         self._bbox_to_anchor_transform = transform
+        self.stale = True
 
     def get_window_extent(self, renderer):
         '''
@@ -1087,11 +1148,11 @@ class AnchoredOffsetbox(OffsetBox):
         self.set_offset(_offset)
 
     def update_frame(self, bbox, fontsize=None):
-            self.patch.set_bounds(bbox.x0, bbox.y0,
-                                  bbox.width, bbox.height)
+        self.patch.set_bounds(bbox.x0, bbox.y0,
+                              bbox.width, bbox.height)
 
-            if fontsize:
-                self.patch.set_mutation_scale(fontsize)
+        if fontsize:
+            self.patch.set_mutation_scale(fontsize)
 
     def draw(self, renderer):
         "draw the artist"
@@ -1114,6 +1175,7 @@ class AnchoredOffsetbox(OffsetBox):
 
         self.get_child().set_offset((px, py))
         self.get_child().draw(renderer)
+        self.stale = False
 
     def _get_anchored_bbox(self, loc, bbox, parentbbox, borderpad):
         """
@@ -1205,6 +1267,7 @@ class OffsetImage(OffsetBox):
                  **kwargs
                  ):
 
+        OffsetBox.__init__(self)
         self._dpi_cor = dpi_cor
 
         self.image = BboxImage(bbox=self.get_window_extent,
@@ -1223,17 +1286,17 @@ class OffsetImage(OffsetBox):
         self.set_zoom(zoom)
         self.set_data(arr)
 
-        OffsetBox.__init__(self)
-
     def set_data(self, arr):
         self._data = np.asarray(arr)
         self.image.set_data(self._data)
+        self.stale = True
 
     def get_data(self):
         return self._data
 
     def set_zoom(self, zoom):
         self._zoom = zoom
+        self.stale = True
 
     def get_zoom(self):
         return self._zoom
@@ -1271,8 +1334,6 @@ class OffsetImage(OffsetBox):
         return mtransforms.Bbox.from_bounds(ox - xd, oy - yd, w, h)
 
     def get_extent(self, renderer):
-
-        # FIXME dpi_cor is never used
         if self._dpi_cor:  # True, do correction
             dpi_cor = renderer.points_to_pixels(1.)
         else:
@@ -1281,7 +1342,7 @@ class OffsetImage(OffsetBox):
         zoom = self.get_zoom()
         data = self.get_data()
         ny, nx = data.shape[:2]
-        w, h = nx * zoom, ny * zoom
+        w, h = dpi_cor * nx * zoom, dpi_cor * ny * zoom
 
         return w, h, 0, 0
 
@@ -1290,7 +1351,8 @@ class OffsetImage(OffsetBox):
         Draw the children
         """
         self.image.draw(renderer)
-        #bbox_artist(self, renderer, fill=False, props=dict(pad=0.))
+        # bbox_artist(self, renderer, fill=False, props=dict(pad=0.))
+        self.stale = False
 
 
 class AnnotationBbox(martist.Artist, _AnnotationBase):
@@ -1330,6 +1392,13 @@ class AnnotationBbox(martist.Artist, _AnnotationBase):
 
         other parameters are identical to that of Annotation.
         """
+
+        martist.Artist.__init__(self, **kwargs)
+        _AnnotationBase.__init__(self,
+                                 xy,
+                                 xycoords=xycoords,
+                                 annotation_clip=annotation_clip)
+
         self.offsetbox = offsetbox
 
         self.arrowprops = arrowprops
@@ -1354,13 +1423,6 @@ class AnnotationBbox(martist.Artist, _AnnotationBase):
             self._arrow_relpos = None
             self.arrow_patch = None
 
-        _AnnotationBase.__init__(self,
-                                 xy,
-                                 xycoords=xycoords,
-                                 annotation_clip=annotation_clip)
-
-        martist.Artist.__init__(self, **kwargs)
-
         #self._fw, self._fh = 0., 0. # for alignment
         self._box_alignment = box_alignment
 
@@ -1383,6 +1445,7 @@ class AnnotationBbox(martist.Artist, _AnnotationBase):
     @xyann.setter
     def xyann(self, xyann):
         self.xybox = xyann
+        self.stale = True
 
     @property
     def anncoords(self):
@@ -1391,6 +1454,7 @@ class AnnotationBbox(martist.Artist, _AnnotationBase):
     @anncoords.setter
     def anncoords(self, coords):
         self.boxcoords = coords
+        self.stale = True
 
     def contains(self, event):
         t, tinfo = self.offsetbox.contains(event)
@@ -1423,6 +1487,7 @@ class AnnotationBbox(martist.Artist, _AnnotationBase):
             s = rcParams["legend.fontsize"]
 
         self.prop = FontProperties(size=s)
+        self.stale = True
 
     def get_fontsize(self, s=None):
         """
@@ -1529,6 +1594,7 @@ class AnnotationBbox(martist.Artist, _AnnotationBase):
             self.patch.draw(renderer)
 
         self.offsetbox.draw(renderer)
+        self.stale = False
 
 
 class DraggableBase(object):
@@ -1627,6 +1693,12 @@ class DraggableBase(object):
         """disconnect the callbacks"""
         for cid in self.cids:
             self.canvas.mpl_disconnect(cid)
+        try:
+            c1 = self._c1
+        except AttributeError:
+            pass
+        else:
+            self.canvas.mpl_disconnect(c1)
 
     def artist_picker(self, artist, evt):
         return self.ref_artist.contains(evt)
@@ -1676,30 +1748,12 @@ class DraggableAnnotation(DraggableBase):
 
     def save_offset(self):
         ann = self.annotation
-        x, y = ann.xyann
-        if isinstance(ann.anncoords, tuple):
-            xcoord, ycoord = ann.anncoords
-            x1, y1 = ann._get_xy(self.canvas.renderer, x, y, xcoord)
-            x2, y2 = ann._get_xy(self.canvas.renderer, x, y, ycoord)
-            ox0, oy0 = x1, y2
-        else:
-            ox0, oy0 = ann._get_xy(self.canvas.renderer, x, y, ann.anncoords)
-
-        self.ox, self.oy = ox0, oy0
-        self.annotation.anncoords = "figure pixels"
-        self.update_offset(0, 0)
+        self.ox, self.oy = ann.get_transform().transform(ann.xyann)
 
     def update_offset(self, dx, dy):
         ann = self.annotation
-        ann.xyann = self.ox + dx, self.oy + dy
-        x, y = ann.xyann
-
-    def finalize_offset(self):
-        loc_in_canvas = self.annotation.xyann
-        self.annotation.anncoords = "axes fraction"
-        pos_axes_fraction = self.annotation.axes.transAxes.inverted()
-        pos_axes_fraction = pos_axes_fraction.transform_point(loc_in_canvas)
-        self.annotation.xyann = tuple(pos_axes_fraction)
+        ann.xyann = ann.get_transform().inverted().transform(
+            (self.ox + dx, self.oy + dy))
 
 
 if __name__ == "__main__":
