@@ -23,6 +23,7 @@ _Plotting commands
   broken_barh - a set of horizontal bars with gaps
   box       - set the axes frame on/off state
   boxplot   - make a box and whisker plot
+  violinplot - make a violin plot
   cla       - clear current axes
   clabel    - label a contour plot
   clf       - clear a figure window
@@ -48,14 +49,12 @@ _Plotting commands
   getp      - get a graphics property
   grid     - set whether gridding is on
   hist     - make a histogram
-  hold     - set the axes hold state
   ioff     - turn interaction mode off
   ion      - turn interaction mode on
   isinteractive - return True if interaction mode is on
   imread   - load image file into array
   imsave   - save array as an image file
   imshow   - plot image data
-  ishold   - return the hold state of the current axes
   legend   - make an axes legend
   locator_params - adjust parameters used in locating axis ticks
   loglog   - a log log plot
@@ -83,7 +82,8 @@ _Plotting commands
   specgram - a spectrogram plot
   spy      - plot sparsity pattern using markers or image
   stem     - make a stem plot
-  subplot  - make a subplot (nrows, ncols, plot_number)
+  subplot  - make one subplot (numrows, numcols, axesnum)
+  subplots - make a figure with a set of (numrows, numcols) subplots
   subplots_adjust - change the params controlling the subplot positions of current figure
   subplot_tool - launch the subplot configuration tool
   suptitle   - add a figure title
@@ -119,7 +119,6 @@ _Plotting commands
   spring - set the default colormap to spring
   summer - set the default colormap to summer
   winter - set the default colormap to winter
-  spectral - set the default colormap to spectral
 
 _Event handling
 
@@ -155,15 +154,14 @@ _Matrix commands
 
 _Probability
 
-  levypdf   - The levy probability density function from the char. func.
   normpdf   - The Gaussian probability density function
   rand      - random numbers from the uniform distribution
   randn     - random numbers from the normal distribution
 
 _Statistics
 
-  amax       - the maximum along dimension m
-  amin       - the minimum along dimension m
+  amax      - the maximum along dimension m
+  amin      - the minimum along dimension m
   corrcoef  - correlation coefficient
   cov       - covariance matrix
   mean      - the mean along dimension m
@@ -172,7 +170,8 @@ _Statistics
   prod      - the product along dimension m
   ptp       - the max-min along dimension m
   std       - the standard deviation along dimension m
-  asum       - the sum along dimension m
+  asum      - the sum along dimension m
+  ksdensity - the kernel density estimate
 
 _Time series analysis
 
@@ -213,87 +212,62 @@ __end
 
 
 """
-from __future__ import print_function
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
+
+import six
+
 import sys, warnings
 
-from cbook import flatten, is_string_like, exception_to_str, \
-     silent_list, iterable, dedent
+from matplotlib.cbook import (
+    flatten, is_string_like, exception_to_str, silent_list, iterable, dedent)
 
-from matplotlib import mpl  # pulls in most modules
+import matplotlib as mpl
+# make mpl.finance module available for backwards compatability, in case folks
+# using pylab interface depended on not having to import it
+with warnings.catch_warnings():
+    warnings.simplefilter("ignore")  # deprecation: moved to a toolkit
+    import matplotlib.finance
 
-from matplotlib.dates import date2num, num2date,\
-        datestr2num, strpdate2num, drange,\
-        epoch2num, num2epoch, mx2num,\
-        DateFormatter, IndexDateFormatter, DateLocator,\
-        RRuleLocator, YearLocator, MonthLocator, WeekdayLocator,\
-        DayLocator, HourLocator, MinuteLocator, SecondLocator,\
-        rrule, MO, TU, WE, TH, FR, SA, SU, YEARLY, MONTHLY,\
-        WEEKLY, DAILY, HOURLY, MINUTELY, SECONDLY, relativedelta
+from matplotlib.dates import (
+    date2num, num2date, datestr2num, strpdate2num, drange, epoch2num,
+    num2epoch, mx2num, DateFormatter, IndexDateFormatter, DateLocator,
+    RRuleLocator, YearLocator, MonthLocator, WeekdayLocator, DayLocator,
+    HourLocator, MinuteLocator, SecondLocator, rrule, MO, TU, WE, TH, FR,
+    SA, SU, YEARLY, MONTHLY, WEEKLY, DAILY, HOURLY, MINUTELY, SECONDLY,
+    relativedelta)
 
-import matplotlib.dates  # Do we need this at all?
-
-# bring all the  symbols in so folks can import them from
+# bring all the symbols in so folks can import them from
 # pylab in one fell swoop
 
-
 ## We are still importing too many things from mlab; more cleanup is needed.
 
-from matplotlib.mlab import griddata, stineman_interp, slopes, \
-    inside_poly, poly_below, poly_between, \
-    is_closed_polygon, path_length, distances_along_curve, vector_lengths
+from matplotlib.mlab import (
+    amap, base_repr, binary_repr, bivariate_normal, center_matrix, csv2rec,
+    demean, detrend, detrend_linear, detrend_mean, detrend_none, dist,
+    dist_point_to_segment, distances_along_curve, entropy, exp_safe,
+    fftsurr, find, frange, get_sparse_matrix, get_xyz_where, griddata,
+    identity, inside_poly, is_closed_polygon, ispower2, isvector, l1norm,
+    l2norm, log2, longest_contiguous_ones, longest_ones, movavg, norm_flat,
+    normpdf, path_length, poly_below, poly_between, prctile, prctile_rank,
+    rec2csv, rec_append_fields, rec_drop_fields, rec_join, rk4, rms_flat,
+    segments_intersect, slopes, stineman_interp, vector_lengths,
+    window_hanning, window_none)
 
-from matplotlib.mlab import window_hanning, window_none,  detrend, demean, \
-     detrend_mean, detrend_none, detrend_linear, entropy, normpdf, levypdf, \
-     find, longest_contiguous_ones, longest_ones, prepca, \
-     prctile, prctile_rank, \
-     center_matrix, rk4, bivariate_normal, get_xyz_where, \
-     get_sparse_matrix, dist, \
-     dist_point_to_segment, segments_intersect, fftsurr, liaupunov, movavg, \
-     exp_safe, \
-     amap, rms_flat, l1norm, l2norm, norm_flat, frange,  identity, \
-     base_repr, binary_repr, log2, ispower2, \
-     rec_append_fields, rec_drop_fields, rec_join, csv2rec, rec2csv, isvector
-
-import matplotlib.mlab as mlab
-import matplotlib.cbook as cbook
+from matplotlib import cbook, mlab, pyplot as plt
+from matplotlib.pyplot import *
 
 from numpy import *
 from numpy.fft import *
 from numpy.random import *
 from numpy.linalg import *
 
-from matplotlib.pyplot import *
-
-# provide the recommended module abbrevs in the pylab namespace
-import matplotlib.pyplot as plt
 import numpy as np
 import numpy.ma as ma
 
-def load(*args, **kwargs):
-    raise  NotImplementedError(load.__doc__)
-load.__doc__ = """\
-    pylab no longer provides a load function, though the old pylab
-    function is still available as matplotlib.mlab.load (you can refer
-    to it in pylab as "mlab.load").  However, for plain text files, we
-    recommend numpy.loadtxt, which was inspired by the old pylab.load
-    but now has more features.  For loading numpy arrays, we recommend
-    numpy.load, and its analog numpy.save, which are available in
-    pylab as np.load and np.save.
-    """
-
-
-def save(*args, **kwargs):
-    raise  NotImplementedError(save.__doc__)
-save.__doc__ = """\
-    pylab no longer provides a save function, though the old pylab
-    function is still available as matplotlib.mlab.save (you can still
-    refer to it in pylab as "mlab.save").  However, for plain text
-    files, we recommend numpy.savetxt.  For saving numpy arrays,
-    we recommend numpy.save, and its analog numpy.load, which are
-    available in pylab as np.save and np.load."""
-
 # don't let numpy's datetime hide stdlib
 import datetime
 
-if sys.version_info > (2, 6, 0):
-    bytes = __builtins__['bytes']
+# This is needed, or bytes will be numpy.random.bytes from
+# "from numpy.random import *" above
+bytes = six.moves.builtins.bytes
