@@ -1,5 +1,8 @@
-#!/usr/local/bin/python2.7
 """
+===========
+Join styles
+===========
+
 Illustrate the three different join styles
 """
 
