@@ -1,5 +1,3 @@
-#!/usr/local/bin/python2.7
-
 """
 Show how to connect to keypress events
 """
@@ -23,5 +21,5 @@ fig.canvas.mpl_connect('key_press_event', press)
 
 ax.plot(np.random.rand(12), np.random.rand(12), 'go')
 xl = ax.set_xlabel('easy come, easy go')
-
+ax.set_title('Press a key')
 plt.show()
