@@ -3,13 +3,13 @@ A little example that shows how the various indexing into the font
 tables relate to one another.  Mainly for mpl developers....
 
 """
+from __future__ import print_function
 import matplotlib
 from matplotlib.ft2font import FT2Font, KERNING_DEFAULT, KERNING_UNFITTED, KERNING_UNSCALED
 
 
-
 #fname = '/usr/share/fonts/sfd/FreeSans.ttf'
-fname = matplotlib.get_data_path() + '/fonts/ttf/Vera.ttf'
+fname = matplotlib.get_data_path() + '/fonts/ttf/DejaVuSans.ttf'
 font = FT2Font(fname)
 font.set_charmap(0)
 
@@ -19,8 +19,7 @@ codes = font.get_charmap().items()
 #for ccode, glyphind in dsu:
 #    try: name = font.get_glyph_name(glyphind)
 #    except RuntimeError: pass
-#    else: print '% 4d % 4d %s %s'%(glyphind, ccode, hex(int(ccode)), name)
-
+#    else: print('% 4d % 4d %s %s' % (glyphind, ccode, hex(int(ccode)), name))
 
 
 # make a charname to charcode and glyphind dictionary
@@ -31,11 +30,11 @@ for ccode, glyphind in codes:
     coded[name] = ccode
     glyphd[name] = glyphind
 
-code =  coded['A']
+code = coded['A']
 glyph = font.load_char(code)
-#print glyph.bbox
-print glyphd['A'], glyphd['V'], coded['A'], coded['V']
-print 'AV', font.get_kerning(glyphd['A'], glyphd['V'], KERNING_DEFAULT)
-print 'AV', font.get_kerning(glyphd['A'], glyphd['V'], KERNING_UNFITTED)
-print 'AV', font.get_kerning(glyphd['A'], glyphd['V'], KERNING_UNSCALED)
-print 'AV', font.get_kerning(glyphd['A'], glyphd['T'], KERNING_UNSCALED)
+#print(glyph.bbox)
+print(glyphd['A'], glyphd['V'], coded['A'], coded['V'])
+print('AV', font.get_kerning(glyphd['A'], glyphd['V'], KERNING_DEFAULT))
+print('AV', font.get_kerning(glyphd['A'], glyphd['V'], KERNING_UNFITTED))
+print('AV', font.get_kerning(glyphd['A'], glyphd['V'], KERNING_UNSCALED))
+print('AV', font.get_kerning(glyphd['A'], glyphd['T'], KERNING_UNSCALED))
