@@ -1,4 +1,3 @@
-#!/usr/local/bin/python2.7
 # a stacked bar plot with errorbars
 import numpy as np
 import matplotlib.pyplot as plt
@@ -12,13 +11,13 @@ womenStd = (3, 5, 2, 3, 3)
 ind = np.arange(N)    # the x locations for the groups
 width = 0.35       # the width of the bars: can also be len(x) sequence
 
-p1 = plt.bar(ind, menMeans, width, color='r', yerr=menStd)
-p2 = plt.bar(ind, womenMeans, width, color='y',
+p1 = plt.bar(ind, menMeans, width, color='#d62728', yerr=menStd)
+p2 = plt.bar(ind, womenMeans, width,
              bottom=menMeans, yerr=womenStd)
 
 plt.ylabel('Scores')
 plt.title('Scores by group and gender')
-plt.xticks(ind + width/2., ('G1', 'G2', 'G3', 'G4', 'G5'))
+plt.xticks(ind, ('G1', 'G2', 'G3', 'G4', 'G5'))
 plt.yticks(np.arange(0, 81, 10))
 plt.legend((p1[0], p2[0]), ('Men', 'Women'))
 
