@@ -1,15 +1,14 @@
-#!/usr/local/bin/python2.7
 # -*- noplot -*-
 """
 Some simple functions to generate colours.
 """
 import numpy as np
-from matplotlib.colors import colorConverter
+from matplotlib import colors as mcolors
 
 
 def pastel(colour, weight=2.4):
     """ Convert colour into a nice pastel shade"""
-    rgb = np.asarray(colorConverter.to_rgb(colour))
+    rgb = np.asarray(mcolors.to_rgba(colour)[:3])
     # scale colour
     maxc = max(rgb)
     if maxc < 1.0 and maxc > 0:
