@@ -1,12 +1,13 @@
-#!/usr/local/bin/python2.7
 """
 Compute the cross spectral density of two signals
 """
 import numpy as np
 import matplotlib.pyplot as plt
 
+
+fig, (ax1, ax2) = plt.subplots(2, 1)
 # make a little extra space between the subplots
-plt.subplots_adjust(wspace=0.5)
+fig.subplots_adjust(hspace=0.5)
 
 dt = 0.01
 t = np.arange(0, 30, dt)
@@ -21,14 +22,12 @@ cnse2 = np.convolve(nse2, r, mode='same')*dt   # colored noise 2
 s1 = 0.01*np.sin(2*np.pi*10*t) + cnse1
 s2 = 0.01*np.sin(2*np.pi*10*t) + cnse2
 
-plt.subplot(211)
-plt.plot(t, s1, 'b-', t, s2, 'g-')
-plt.xlim(0, 5)
-plt.xlabel('time')
-plt.ylabel('s1 and s2')
-plt.grid(True)
+ax1.plot(t, s1, t, s2)
+ax1.set_xlim(0, 5)
+ax1.set_xlabel('time')
+ax1.set_ylabel('s1 and s2')
+ax1.grid(True)
 
-plt.subplot(212)
-cxy, f = plt.csd(s1, s2, 256, 1./dt)
-plt.ylabel('CSD (db)')
+cxy, f = ax2.csd(s1, s2, 256, 1./dt)
+ax2.set_ylabel('CSD (db)')
 plt.show()
