@@ -1,13 +1,15 @@
-#!/usr/local/bin/python2.7
 # -*- noplot -*-
 # print png to standard out
 # usage: python print_stdout.py > somefile.png
+
 import sys
 import matplotlib
 matplotlib.use('Agg')
-from pylab import *
+import matplotlib.pyplot as plt
 
-plot([1,2,3])
+plt.plot([1, 2, 3])
 
-savefig(sys.stdout)
-show()
+if sys.version_info[0] >= 3:
+    plt.savefig(sys.stdout.buffer)
+else:
+    plt.savefig(sys.stdout)
