@@ -1,6 +1,3 @@
-#!/usr/local/bin/python2.7
-
-from __future__ import print_function, division
 """
 This is used to drive many of the examples across the backends, for
 regression testing, and comparing backend efficiency.
@@ -20,6 +17,7 @@ option parsing error with the driver script, separate them from driver
 switches with a --.
 """
 
+from __future__ import print_function, division
 import os
 import time
 import sys
@@ -45,7 +43,8 @@ dirs = dict(files=os.path.join('..', 'lines_bars_and_markers'),
             pylab=os.path.join('..', 'pylab_examples'),
             api=os.path.join('..', 'api'),
             units=os.path.join('..', 'units'),
-            mplot3d=os.path.join('..', 'mplot3d'))
+            mplot3d=os.path.join('..', 'mplot3d'),
+            colors=os.path.join('..', 'color'))
 
 
 # files in each dir
@@ -66,6 +65,7 @@ files['shapes'] = [
     ]
 
 files['colors'] = [
+    'color_cycle_default.py',
     'color_cycle_demo.py',
     ]
 
@@ -144,8 +144,6 @@ files['pylab'] = [
     'custom_ticker1.py',
     'customize_rc.py',
     'dashpointlabel.py',
-    'date_demo1.py',
-    'date_demo2.py',
     'date_demo_convert.py',
     'date_demo_rrule.py',
     'date_index_formatter.py',
@@ -164,7 +162,6 @@ files['pylab'] = [
     'figure_title.py',
     'fill_between_demo.py',
     'fill_spiral.py',
-    'finance_demo.py',
     'findobj_demo.py',
     'fonts_demo.py',
     'fonts_demo_kw.py',
@@ -202,7 +199,6 @@ files['pylab'] = [
     'masked_demo.py',
     'mathtext_demo.py',
     'mathtext_examples.py',
-    'matplotlib_icon.py',
     'matshow.py',
     'mri_demo.py',
     'mri_with_eeg.py',
@@ -238,7 +234,6 @@ files['pylab'] = [
     'stem_plot.py',
     'step_demo.py',
     'stix_fonts_demo.py',
-    'stock_demo.py',
     'subplots_adjust.py',
     'symlog_demo.py',
     'table_demo.py',
