@@ -1,4 +1,8 @@
 """
+==============
+Dropped spines
+==============
+
 Demo of spines offset from the axes (a.k.a. "dropped spines").
 """
 import numpy as np
