@@ -1,4 +1,3 @@
-#!/usr/local/bin/python2.7
 
 # embedding_in_qt4.py --- Simple Qt4 application embedding matplotlib canvases
 #
@@ -34,12 +33,9 @@ class MyMplCanvas(FigureCanvas):
     def __init__(self, parent=None, width=5, height=4, dpi=100):
         fig = Figure(figsize=(width, height), dpi=dpi)
         self.axes = fig.add_subplot(111)
-        # We want the axes cleared every time plot() is called
-        self.axes.hold(False)
 
         self.compute_initial_figure()
 
-        #
         FigureCanvas.__init__(self, fig)
         self.setParent(parent)
 
@@ -76,7 +72,7 @@ class MyDynamicMplCanvas(MyMplCanvas):
     def update_figure(self):
         # Build a list of 4 random integers between 0 and 10 (both inclusive)
         l = [random.randint(0, 10) for i in range(4)]
-
+        self.axes.cla()
         self.axes.plot([0, 1, 2, 3], l, 'r')
         self.draw()
 
